==> ruby20-rmagick-2.13.1p4.tgz: lib/ruby/gems/2.0/gems/rmagick-2.13.1/ext/RMagick/extconf.h <==
#ifndef EXTCONF_H
#define EXTCONF_H
#define HAVE_STDINT_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_WAND_MAGICKWAND_H 1
#define HAVE_SNPRINTF 1
#define HAVE_ACQUIREIMAGE 1
#define HAVE_AFFINITYIMAGE 1
#define HAVE_AFFINITYIMAGES 1
#define HAVE_AUTOGAMMAIMAGECHANNEL 1
#define HAVE_AUTOLEVELIMAGECHANNEL 1
#define HAVE_BLUESHIFTIMAGE 1
#define HAVE_CONSTITUTECOMPONENTTERMINUS 1
#define HAVE_DESKEWIMAGE 1
#define HAVE_ENCIPHERIMAGE 1
#define HAVE_EQUALIZEIMAGECHANNEL 1
#define HAVE_FLOODFILLPAINTIMAGE 1
#define HAVE_FUNCTIONIMAGECHANNEL 1
#define HAVE_GETAUTHENTICINDEXQUEUE 1
#define HAVE_GETAUTHENTICPIXELS 1
#define HAVE_GETIMAGEALPHACHANNEL 1
#define HAVE_GETVIRTUALPIXELS 1
#define HAVE_LEVELIMAGECOLORS 1
#define HAVE_LEVELCOLORSIMAGECHANNEL 1
#define HAVE_LEVELIZEIMAGECHANNEL 1
#define HAVE_LIQUIDRESCALEIMAGE 1
#define HAVE_MAGICKLIBADDENDUM 1
#define HAVE_OPAQUEPAINTIMAGECHANNEL 1
#define HAVE_QUEUEAUTHENTICPIXELS 1
#define HAVE_REMAPIMAGE 1
#define HAVE_REMOVEIMAGEARTIFACT 1
#define HAVE_SELECTIVEBLURIMAGECHANNEL 1
#define HAVE_SETIMAGEALPHACHANNEL 1
#define HAVE_SETIMAGEARTIFACT 1
#define HAVE_SETMAGICKMEMORYMETHODS 1
#define HAVE_SPARSECOLORIMAGE 1
#define HAVE_SYNCAUTHENTICPIXELS 1
#define HAVE_TRANSPARENTPAINTIMAGE 1
#define HAVE_TRANSPARENTPAINTIMAGECHROMA 1
#define HAVE_NEW_QUERYMAGICKCOLORNAME 1
#define HAVE_IMAGE_TYPE 1
#define HAVE_ST_TYPE 1
#define HAVE_DRAWINFO_KERNING 1
#define HAVE_ST_KERNING 1
#define HAVE_DRAWINFO_INTERLINE_SPACING 1
#define HAVE_ST_INTERLINE_SPACING 1
#define HAVE_DRAWINFO_INTERWORD_SPACING 1
#define HAVE_ST_INTERWORD_SPACING 1
#define HAVE_TYPE_DITHERMETHOD 1
#define HAVE_TYPE_MAGICKFUNCTION 1
#define HAVE_TYPE_IMAGELAYERMETHOD 1
#define HAVE_TYPE_LONG_DOUBLE 1
#define HAVE_ENUM_COPYALPHACHANNEL 1
#define HAVE_ENUM_BACKGROUNDALPHACHANNEL 1
#define HAVE_ENUM_BLURCOMPOSITEOP 1
#define HAVE_ENUM_DISTORTCOMPOSITEOP 1
#define HAVE_ENUM_LINEARBURNCOMPOSITEOP 1
#define HAVE_ENUM_LINEARDODGECOMPOSITEOP 1
#define HAVE_ENUM_MATHEMATICSCOMPOSITEOP 1
#define HAVE_ENUM_PEGTOPLIGHTCOMPOSITEOP 1
#define HAVE_ENUM_PINLIGHTCOMPOSITEOP 1
#define HAVE_ENUM_VIVIDLIGHTCOMPOSITEOP 1
#define HAVE_ENUM_DXT1COMPRESSION 1
#define HAVE_ENUM_DXT3COMPRESSION 1
#define HAVE_ENUM_DXT5COMPRESSION 1
#define HAVE_ENUM_ZIPSCOMPRESSION 1
#define HAVE_ENUM_PIZCOMPRESSION 1
#define HAVE_ENUM_PXR24COMPRESSION 1
#define HAVE_ENUM_B44COMPRESSION 1
#define HAVE_ENUM_B44ACOMPRESSION 1
#define HAVE_ENUM_BARRELDISTORTION 1
#define HAVE_ENUM_BARRELINVERSEDISTORTION 1
#define HAVE_ENUM_BILINEARFORWARDDISTORTION 1
#define HAVE_ENUM_BILINEARREVERSEDISTORTION 1
#define HAVE_ENUM_DEPOLARDISTORTION 1
#define HAVE_ENUM_POLARDISTORTION 1
#define HAVE_ENUM_POLYNOMIALDISTORTION 1
#define HAVE_ENUM_SHEPARDSDISTORTION 1
#define HAVE_ENUM_NODITHERMETHOD 1
#define HAVE_ENUM_KAISERFILTER 1
#define HAVE_ENUM_WELSHFILTER 1
#define HAVE_ENUM_PARZENFILTER 1
#define HAVE_ENUM_LAGRANGEFILTER 1
#define HAVE_ENUM_BOHMANFILTER 1
#define HAVE_ENUM_BARTLETTFILTER 1
#define HAVE_ENUM_SENTINELFILTER 1
#define HAVE_ENUM_POWEVALUATEOPERATOR 1
#define HAVE_ENUM_LOGEVALUATEOPERATOR 1
#define HAVE_ENUM_THRESHOLDEVALUATEOPERATOR 1
#define HAVE_ENUM_THRESHOLDBLACKEVALUATEOPERATOR 1
#define HAVE_ENUM_THRESHOLDWHITEEVALUATEOPERATOR 1
#define HAVE_ENUM_GAUSSIANNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_IMPULSENOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_LAPLACIANNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_MULTIPLICATIVENOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_POISSONNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_UNIFORMNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_COSINEEVALUATEOPERATOR 1
#define HAVE_ENUM_SINEEVALUATEOPERATOR 1
#define HAVE_ENUM_ADDMODULUSEVALUATEOPERATOR 1
#define HAVE_ENUM_ARCSINFUNCTION 1
#define HAVE_ENUM_ARCTANFUNCTION 1
#define HAVE_ENUM_POLYNOMIALFUNCTION 1
#define HAVE_ENUM_SINUSOIDFUNCTION 1
#define HAVE_ENUM_FLATTENLAYER 1
#define HAVE_ENUM_MERGELAYER 1
#define HAVE_ENUM_MOSAICLAYER 1
#define HAVE_ENUM_TRIMBOUNDSLAYER 1
#define HAVE_ENUM_HORIZONTALTILEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_VERTICALTILEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_HORIZONTALTILEEDGEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_VERTICALTILEEDGEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_CHECKERTILEVIRTUALPIXELMETHOD 1
#define HAVE_RUBY_IO_H 1
#define HAVE_RB_FRAME_THIS_FUNC 1
#define RUBY_VERSION_STRING ruby 2.0.0
#define RMAGICK_VERSION_STRING RMagick 2.13.1
#endif

==> ruby20-rmagick-2.15.2.tgz: lib/ruby/gems/2.0/gems/rmagick-2.15.2/ext/RMagick/extconf.h <==
#ifndef EXTCONF_H
#define EXTCONF_H
#define HAVE_STDINT_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_WAND_MAGICKWAND_H 1
#define HAVE_SNPRINTF 1
#define HAVE_ACQUIREIMAGE 1
#define HAVE_AFFINITYIMAGE 1
#define HAVE_AFFINITYIMAGES 1
#define HAVE_AUTOGAMMAIMAGECHANNEL 1
#define HAVE_AUTOLEVELIMAGECHANNEL 1
#define HAVE_BLUESHIFTIMAGE 1
#define HAVE_COLORMATRIXIMAGE 1
#define HAVE_CONSTITUTECOMPONENTTERMINUS 1
#define HAVE_DESKEWIMAGE 1
#define HAVE_DESTROYCONSTITUTE 1
#define HAVE_ENCIPHERIMAGE 1
#define HAVE_EQUALIZEIMAGECHANNEL 1
#define HAVE_EVALUATEIMAGES 1
#define HAVE_FLOODFILLPAINTIMAGE 1
#define HAVE_FUNCTIONIMAGECHANNEL 1
#define HAVE_GETAUTHENTICINDEXQUEUE 1
#define HAVE_GETAUTHENTICPIXELS 1
#define HAVE_GETIMAGEALPHACHANNEL 1
#define HAVE_GETMAGICKFEATURES 1
#define HAVE_GETVIRTUALPIXELS 1
#define HAVE_LEVELIMAGECOLORS 1
#define HAVE_LEVELCOLORSIMAGECHANNEL 1
#define HAVE_LEVELIZEIMAGECHANNEL 1
#define HAVE_LIQUIDRESCALEIMAGE 1
#define HAVE_MAGICKLIBADDENDUM 1
#define HAVE_OPAQUEPAINTIMAGECHANNEL 1
#define HAVE_QUEUEAUTHENTICPIXELS 1
#define HAVE_REMAPIMAGE 1
#define HAVE_REMAPIMAGES 1
#define HAVE_REMOVEIMAGEARTIFACT 1
#define HAVE_SELECTIVEBLURIMAGECHANNEL 1
#define HAVE_SETIMAGEALPHACHANNEL 1
#define HAVE_SETIMAGEARTIFACT 1
#define HAVE_SETMAGICKMEMORYMETHODS 1
#define HAVE_SPARSECOLORIMAGE 1
#define HAVE_STATISTICIMAGE 1
#define HAVE_SYNCAUTHENTICPIXELS 1
#define HAVE_TRANSFORMIMAGECOLORSPACE 1
#define HAVE_TRANSPARENTPAINTIMAGE 1
#define HAVE_TRANSPARENTPAINTIMAGECHROMA 1
#define HAVE_NEW_QUERYMAGICKCOLORNAME 1
#define HAVE_IMAGE_TYPE 1
#define HAVE_ST_TYPE 1
#define HAVE_DRAWINFO_KERNING 1
#define HAVE_ST_KERNING 1
#define HAVE_DRAWINFO_INTERLINE_SPACING 1
#define HAVE_ST_INTERLINE_SPACING 1
#define HAVE_DRAWINFO_INTERWORD_SPACING 1
#define HAVE_ST_INTERWORD_SPACING 1
#define HAVE_TYPE_DITHERMETHOD 1
#define HAVE_TYPE_MAGICKFUNCTION 1
#define HAVE_TYPE_IMAGELAYERMETHOD 1
#define HAVE_TYPE_LONG_DOUBLE 1
#define HAVE_ENUM_COPYALPHACHANNEL 1
#define HAVE_ENUM_BACKGROUNDALPHACHANNEL 1
#define HAVE_ENUM_REMOVEALPHACHANNEL 1
#define HAVE_ENUM_BLURCOMPOSITEOP 1
#define HAVE_ENUM_DISTORTCOMPOSITEOP 1
#define HAVE_ENUM_LINEARBURNCOMPOSITEOP 1
#define HAVE_ENUM_LINEARDODGECOMPOSITEOP 1
#define HAVE_ENUM_MATHEMATICSCOMPOSITEOP 1
#define HAVE_ENUM_PEGTOPLIGHTCOMPOSITEOP 1
#define HAVE_ENUM_PINLIGHTCOMPOSITEOP 1
#define HAVE_ENUM_VIVIDLIGHTCOMPOSITEOP 1
#define HAVE_ENUM_DXT1COMPRESSION 1
#define HAVE_ENUM_DXT3COMPRESSION 1
#define HAVE_ENUM_DXT5COMPRESSION 1
#define HAVE_ENUM_ZIPSCOMPRESSION 1
#define HAVE_ENUM_PIZCOMPRESSION 1
#define HAVE_ENUM_PXR24COMPRESSION 1
#define HAVE_ENUM_B44COMPRESSION 1
#define HAVE_ENUM_B44ACOMPRESSION 1
#define HAVE_ENUM_BARRELDISTORTION 1
#define HAVE_ENUM_BARRELINVERSEDISTORTION 1
#define HAVE_ENUM_BILINEARFORWARDDISTORTION 1
#define HAVE_ENUM_BILINEARREVERSEDISTORTION 1
#define HAVE_ENUM_DEPOLARDISTORTION 1
#define HAVE_ENUM_POLARDISTORTION 1
#define HAVE_ENUM_POLYNOMIALDISTORTION 1
#define HAVE_ENUM_SHEPARDSDISTORTION 1
#define HAVE_ENUM_NODITHERMETHOD 1
#define HAVE_ENUM_KAISERFILTER 1
#define HAVE_ENUM_WELSHFILTER 1
#define HAVE_ENUM_PARZENFILTER 1
#define HAVE_ENUM_LAGRANGEFILTER 1
#define HAVE_ENUM_BOHMANFILTER 1
#define HAVE_ENUM_BARTLETTFILTER 1
#define HAVE_ENUM_SENTINELFILTER 1
#define HAVE_ENUM_POWEVALUATEOPERATOR 1
#define HAVE_ENUM_LOGEVALUATEOPERATOR 1
#define HAVE_ENUM_THRESHOLDEVALUATEOPERATOR 1
#define HAVE_ENUM_THRESHOLDBLACKEVALUATEOPERATOR 1
#define HAVE_ENUM_THRESHOLDWHITEEVALUATEOPERATOR 1
#define HAVE_ENUM_GAUSSIANNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_IMPULSENOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_LAPLACIANNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_MULTIPLICATIVENOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_POISSONNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_UNIFORMNOISEEVALUATEOPERATOR 1
#define HAVE_ENUM_COSINEEVALUATEOPERATOR 1
#define HAVE_ENUM_SINEEVALUATEOPERATOR 1
#define HAVE_ENUM_ADDMODULUSEVALUATEOPERATOR 1
#define HAVE_ENUM_ARCSINFUNCTION 1
#define HAVE_ENUM_ARCTANFUNCTION 1
#define HAVE_ENUM_POLYNOMIALFUNCTION 1
#define HAVE_ENUM_SINUSOIDFUNCTION 1
#define HAVE_ENUM_FLATTENLAYER 1
#define HAVE_ENUM_MERGELAYER 1
#define HAVE_ENUM_MOSAICLAYER 1
#define HAVE_ENUM_TRIMBOUNDSLAYER 1
#define HAVE_ENUM_HORIZONTALTILEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_VERTICALTILEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_HORIZONTALTILEEDGEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_VERTICALTILEEDGEVIRTUALPIXELMETHOD 1
#define HAVE_ENUM_CHECKERTILEVIRTUALPIXELMETHOD 1
#define HAVE_RUBY_IO_H 1
#define HAVE_RB_FRAME_THIS_FUNC 1
#define RUBY_VERSION_STRING ruby 2.0.0
#define RMAGICK_VERSION_STRING RMagick 2.15.2
#endif
